@@ -29,7 +29,7 @@ def main():
     private_key, public_key = generate_key_pair()
     iota = IotaClient(private_key, public_key)
 
-    raw_cid = 'cidhash'
+    raw_cid = 'bafybeifk6fyfmrgylejsujeido7kob7ysp6353wb5b7i5nhc64kzkxdvs4'
     service_message = 'hello world'
     message_id, index = iota.create_message(
         raw_cid=raw_cid,
